Learn R Programming

eaf (version 1.06)

SPEA2minstoptimeRichmond: Results of SPEA2 when minimising electrical cost and maximising the minimum idle time of pumps on Richmond water network.

Description

Results of SPEA2 when minimising electrical cost and maximising the minimum idle time of pumps on Richmond water network. The data has the only goal of providing an example of use of eafplot.

Usage

data(SPEA2minstoptimeRichmond)

Arguments

format

A data frame as produced by read.data.sets. The second column measures time in seconds and corresponds to a maximisation problem.

source

Manuel López-Ibáñez{Lopez-Ibanez}. Operational Optimisation of Water Distribution Networks. PhD thesis, School of Engineering and the Built Environment, Edinburgh Napier University, UK, 2009.

Examples

Run this code
data(HybridGA)
data(SPEA2minstoptimeRichmond)
SPEA2minstoptimeRichmond[,2] <- SPEA2minstoptimeRichmond[,2] / 60
eafplot (SPEA2minstoptimeRichmond, xlab = expression(C[E]),
         ylab = "Minimum idle time (minutes)",
         las = 1, log = "y", maximise = c(FALSE, TRUE))

Run the code above in your browser using DataLab