Learn R Programming

eaf (version 1.0)

SPEA2relativeVanzyl: Results of SPEA2 with relative time-controlled triggers on Vanzyl's water network.

Description

Results of SPEA2 with relative time-controlled triggers on Vanzyl's water network. The data has the only goal of providing an example of use of eafplot.

Usage

data(SPEA2relativeVanzyl)

Arguments

format

A data frame as produced by read.data.sets.

source

Manuel López-Ibáñez{Lopez-Ibanez}. Operational Optimisation of Water Distribution Networks. PhD thesis, School of Engineering and the Built Environment, Edinburgh Napier University, UK, 2009.

Examples

Run this code
data(HybridGA)
data(SPEA2relativeVanzyl)
eafplot(SPEA2relativeVanzyl, percentiles = c(25, 50, 75), 
        xlab = expression(C[E]), ylab = "Total switches", xlim = c(320, 400),
        extra.points = HybridGA$vanzyl, extra.legend = "Hybrid GA")

Run the code above in your browser using DataLab